from invenio_drafts_resources.resources import RecordResource


class CommonResource(RecordResource):
    """CommonRecord resource."""

    # here you can for example redefine
    # create_url_rules function to add your own rules
